==> qtjambi-network-debuginfo-macos-5.15.17.jar: sources/QtJambiNetwork/QTcpServer_shell.h <==
#ifndef QTCPSERVER_SHELL_H
#define QTCPSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetwork/qtcpserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qtcpsocket.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QTcpServer_shell : public QTcpServer, public QtJambiShellInterface
{
public:
    QTcpServer_shell(QObject* parent0 = nullptr);
    ~QTcpServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    void incomingConnection(qintptr handle0) override;
    QTcpSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTcpServer_access : public QTcpServer
{
    void __qt_addPendingConnection_QTcpSocket_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID socket0);
    jboolean __qt_hasPendingConnections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_incomingConnection_qintptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong handle0);
    jobject __qt_nextPendingConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QTCPSERVER_SHELL_H

==> qtjambi-network-debuginfo-macos-6.5.3.jar: sources/QtJambiNetwork/QTcpServer_shell.h <==
#ifndef QTCPSERVER_SHELL_H
#define QTCPSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetwork/qtcpserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qtcpsocket.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QTcpServer_shell : public QTcpServer, public QtJambiShellInterface
{
public:
    QTcpServer_shell(QObject* parent0 = nullptr);
    ~QTcpServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    void incomingConnection(qintptr handle0) override;
    QTcpSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTcpServer_access : public QTcpServer
{
    void __qt_addPendingConnection_QTcpSocket_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID socket0);
    jboolean __qt_hasPendingConnections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_incomingConnection_qintptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong handle0);
    jobject __qt_nextPendingConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QTCPSERVER_SHELL_H
